package fr.enssat.BoulderDash.controllers;

import fr.enssat.BoulderDash.models.LevelModel;
import fr.enssat.BoulderDash.views.LevelEditorView;

import java.awt.event.KeyEvent;


/**
 * LevelEditorKeyController
 *
 * Manages the key events controller.
 *
 * @author      Valerian Saliou <valerian@valeriansaliou.name>
 * @since       2015-06-21
 */
public class LevelEditorKeyController extends KeyController {
    private LevelEditorView levelEditorView;
	private boolean capLocks;

    /**
     * Class constructor
     *
     * @param  levelModel       Level model
     * @param  levelEditorView  Level editor view
     */
    public LevelEditorKeyController(LevelModel levelModel, LevelEditorView levelEditorView) {
        super(levelModel);
        this.capLocks = false;
        this.levelEditorView = levelEditorView;
    }

    @Override
    public void keyPressed(KeyEvent e) {
        int keyCode = e.getKeyCode();
        LevelModel levelModel = getLevelModel();

        switch (keyCode) {
            // Direction: UP
            case KeyEvent.VK_UP:
                levelModel.decrementCursorYPosition();
                break;

            // Direction: DOWN
            case KeyEvent.VK_DOWN:
                levelModel.incrementCursorYPosition();
                break;

            // Direction: LEFT
            case KeyEvent.VK_LEFT:
                levelModel.decrementCursorXPosition();
                break;

            // Direction: RIGHT
            case KeyEvent.VK_RIGHT:
                levelModel.incrementCursorXPosition();
                break;

            // Key: SPACE
            case KeyEvent.VK_SPACE:
                levelModel.triggerBlockChange(this.levelEditorView.getPickedBlockValue());
                break;
            
            case 16:
                this.capLocks = !capLocks;
                break;
        }

        // Hold block change (quick edit)
        if(capLocks) {
        	levelModel.triggerBlockChange(this.levelEditorView.getPickedBlockValue());
        }
    }

    @Override
    public void keyReleased(KeyEvent e) {
        // Do nothing.
    }

    @Override
    public void keyTyped(KeyEvent e) {
        // Do nothing.
    }
}
